/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataHcpWaypointActionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the Action.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.97.0/docs/data-sources/waypoint_action#id DataHcpWaypointAction#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Action.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.97.0/docs/data-sources/waypoint_action#name DataHcpWaypointAction#name}
    */
    readonly name?: string;
    /**
    * The ID of the HCP project where the Waypoint Action is located.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.97.0/docs/data-sources/waypoint_action#project_id DataHcpWaypointAction#project_id}
    */
    readonly projectId?: string;
}
export interface DataHcpWaypointActionRequestCustom {
}
export declare function dataHcpWaypointActionRequestCustomToTerraform(struct?: DataHcpWaypointActionRequestCustom): any;
export declare function dataHcpWaypointActionRequestCustomToHclTerraform(struct?: DataHcpWaypointActionRequestCustom): any;
export declare class DataHcpWaypointActionRequestCustomOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataHcpWaypointActionRequestCustom | undefined;
    set internalValue(value: DataHcpWaypointActionRequestCustom | undefined);
    get body(): string;
    private _headers;
    get headers(): cdktf.StringMap;
    get method(): string;
    get url(): string;
}
export interface DataHcpWaypointActionRequest {
}
export declare function dataHcpWaypointActionRequestToTerraform(struct?: DataHcpWaypointActionRequest): any;
export declare function dataHcpWaypointActionRequestToHclTerraform(struct?: DataHcpWaypointActionRequest): any;
export declare class DataHcpWaypointActionRequestOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataHcpWaypointActionRequest | undefined;
    set internalValue(value: DataHcpWaypointActionRequest | undefined);
    private _custom;
    get custom(): DataHcpWaypointActionRequestCustomOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.97.0/docs/data-sources/waypoint_action hcp_waypoint_action}
*/
export declare class DataHcpWaypointAction extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "hcp_waypoint_action";
    /**
    * Generates CDKTF code for importing a DataHcpWaypointAction resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataHcpWaypointAction to import
    * @param importFromId The id of the existing DataHcpWaypointAction that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/hcp/0.97.0/docs/data-sources/waypoint_action#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataHcpWaypointAction to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.97.0/docs/data-sources/waypoint_action hcp_waypoint_action} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataHcpWaypointActionConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataHcpWaypointActionConfig);
    get description(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get organizationId(): string;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _request;
    get request(): DataHcpWaypointActionRequestOutputReference;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
